var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import React from "react";
import PropTypes from "prop-types";
import { GlobalNav as VanillaGlobalNav } from "hig-vanilla";
import HIGAdapter, { MapsEventListener, MapsPropToMethod, MountsAnyChild, MountsHIGChild } from "../HIGAdapter";
import TopNavAdapter from "./TopNav/TopNavAdapter";
import SideNavAdapter from "./SideNav/SideNavAdapter";
import SubNavAdapter from "./SubNav/SubNavAdapter";
import SideNav from "../../elements/components/GlobalNav/SideNav/SideNav";

function sortChildren(children) {
  return {
    topNav: children.find(function (child) {
      return child.type === TopNavAdapter;
    }),
    sideNav: children.find(function (child) {
      return child.type === SideNavAdapter || child.type === SideNav;
    }),
    subNav: children.find(function (child) {
      return child.type === SubNavAdapter;
    }),
    otherChildren: children.filter(function (child) {
      return ![TopNavAdapter, SideNavAdapter, SubNavAdapter, SideNav].includes(child.type);
    })
  };
}

export default function GlobalNavAdapter(props) {
  var _sortChildren = sortChildren(React.Children.toArray(props.children)),
      otherChildren = _sortChildren.otherChildren,
      topNav = _sortChildren.topNav,
      sideNav = _sortChildren.sideNav,
      subNav = _sortChildren.subNav;

  return React.createElement(
    HIGAdapter,
    _extends({
      displayName: "GlobalNav",
      HIGConstructor: VanillaGlobalNav
    }, props),
    function (adapterProps) {
      return React.createElement(
        "div",
        null,
        React.createElement(MapsEventListener, _extends({
          listener: "onHoverOutside",
          handler: props.onHoverOutside
        }, adapterProps)),
        React.createElement(
          MapsPropToMethod,
          _extends({ value: props.sideNavOpen }, adapterProps),
          function (instance, value) {
            return value ? instance.showSideNav() : instance.hideSideNav();
          }
        ),
        React.createElement(
          MountsAnyChild,
          _extends({ mounter: "addSlot" }, adapterProps),
          otherChildren
        ),
        React.createElement(
          MountsHIGChild,
          adapterProps,
          sideNav
        ),
        React.createElement(
          MountsHIGChild,
          adapterProps,
          subNav
        ),
        React.createElement(
          MountsHIGChild,
          adapterProps,
          topNav
        )
      );
    }
  );
}

GlobalNavAdapter.propTypes = {
  children: PropTypes.node,
  onHoverOutside: PropTypes.func,
  sideNavOpen: PropTypes.bool
};

GlobalNavAdapter.defaultProps = {
  children: undefined,
  onHoverOutside: undefined,
  sideNavOpen: undefined
};
GlobalNavAdapter.__docgenInfo = {
  "description": "",
  "displayName": "GlobalNavAdapter",
  "props": {
    "children": {
      "type": {
        "name": "node"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "undefined",
        "computed": true
      }
    },
    "onHoverOutside": {
      "type": {
        "name": "func"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "undefined",
        "computed": true
      }
    },
    "sideNavOpen": {
      "type": {
        "name": "bool"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "undefined",
        "computed": true
      }
    }
  }
};