var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import React from "react";
import PropTypes from "prop-types";
import { GlobalNav as VanillaGlobalNav } from "hig-vanilla";
import HIGAdapter, { MapsEventListener, MapsPropToMethod, MountedByHIGParentList, MountsHIGChild, MountsHIGChildList } from "../../HIGAdapter";

import CollapseAdapter from "./CollapseAdapter";
import Collapse from "../../../elements/components/GlobalNav/SideNav/ModuleCollapse";
import SubmoduleAdapter from "./SubmoduleAdapter";
import Submodule from "../../../elements/components/GlobalNav/SideNav/Submodule";

function sortChildren(children) {
  return {
    collapse: children.find(function (child) {
      return [CollapseAdapter, Collapse].includes(child.type);
    }),
    submodules: children.filter(function (child) {
      return [SubmoduleAdapter, Submodule].includes(child.type);
    })
  };
}

function ModuleAdapter(props) {
  var _sortChildren = sortChildren(React.Children.toArray(props.children)),
      collapse = _sortChildren.collapse,
      submodules = _sortChildren.submodules;

  return React.createElement(
    HIGAdapter,
    _extends({
      displayName: "Module",
      HIGConstructor: VanillaGlobalNav._partials.SideNav._partials.SideNavFull._partials.Group._partials.Module
    }, props),
    function (adapterProps) {
      return React.createElement(
        "div",
        null,
        React.createElement(MountedByHIGParentList, _extends({ mounter: "addModule" }, adapterProps)),
        React.createElement(MapsEventListener, _extends({
          listener: "onClick",
          handler: props.onClick
        }, adapterProps)),
        React.createElement(MapsEventListener, _extends({
          listener: "onHover",
          handler: props.onHover
        }, adapterProps)),
        React.createElement(MapsPropToMethod, _extends({
          value: props.icon,
          setter: "setIcon"
        }, adapterProps)),
        React.createElement(MapsPropToMethod, _extends({
          value: props.link,
          setter: "setLink"
        }, adapterProps)),
        React.createElement(MapsPropToMethod, _extends({
          value: props.title,
          setter: "setTitle"
        }, adapterProps)),
        React.createElement(MapsPropToMethod, _extends({
          value: props.target,
          setter: "setTarget"
        }, adapterProps)),
        React.createElement(
          MapsPropToMethod,
          _extends({ value: props.active }, adapterProps),
          function (instance, value) {
            return value ? instance.activate() : instance.deactivate();
          }
        ),
        React.createElement(
          MapsPropToMethod,
          _extends({ value: props.activeChildren }, adapterProps),
          function (instance, value) {
            return value ? instance.activateChildren() : instance.deactivateChildren();
          }
        ),
        React.createElement(
          MountsHIGChild,
          adapterProps,
          collapse
        ),
        submodules.length > 0 ? React.createElement(
          MountsHIGChildList,
          adapterProps,
          submodules
        ) : null
      );
    }
  );
}

ModuleAdapter.propTypes = {
  children: PropTypes.node,
  icon: PropTypes.string,
  link: PropTypes.string,
  title: PropTypes.string,
  target: PropTypes.string,
  active: PropTypes.bool,
  activeChildren: PropTypes.bool,
  onClick: PropTypes.func,
  onHover: PropTypes.func
};

ModuleAdapter.defaultProps = {
  children: [],
  icon: undefined,
  link: undefined,
  title: undefined,
  active: false,
  activeChildren: false,
  onClick: undefined,
  onHover: undefined
};

export default ModuleAdapter;
ModuleAdapter.__docgenInfo = {
  "description": "",
  "displayName": "ModuleAdapter",
  "props": {
    "children": {
      "type": {
        "name": "node"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "[]",
        "computed": false
      }
    },
    "icon": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "undefined",
        "computed": true
      }
    },
    "link": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "undefined",
        "computed": true
      }
    },
    "title": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "undefined",
        "computed": true
      }
    },
    "target": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": ""
    },
    "active": {
      "type": {
        "name": "bool"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "false",
        "computed": false
      }
    },
    "activeChildren": {
      "type": {
        "name": "bool"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "false",
        "computed": false
      }
    },
    "onClick": {
      "type": {
        "name": "func"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "undefined",
        "computed": true
      }
    },
    "onHover": {
      "type": {
        "name": "func"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "undefined",
        "computed": true
      }
    }
  }
};