var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import React from "react";
import PropTypes from "prop-types";
import { GlobalNav as VanillaGlobalNav } from "hig-vanilla";
import HIGAdapter, { MapsPropToMethod, MapsEventListener, MountedByHIGParent, MountsAnyChild, MountsHIGChild, MountsHIGChildList } from "../../HIGAdapter";

import LinkAdapter from "./LinkAdapter";
import SearchAdapter from "./SearchAdapter";
import GroupAdapter from "./GroupAdapter";
import Search from "../../../elements/components/GlobalNav/SideNav/Search";

function sortChildren(children) {
  return {
    groups: children.filter(function (child) {
      return child.type === GroupAdapter;
    }),
    links: children.filter(function (child) {
      return child.type === LinkAdapter;
    }),
    search: children.find(function (child) {
      return child.type === SearchAdapter || child.type === Search;
    }),
    otherChildren: children.filter(function (child) {
      return ![LinkAdapter, SearchAdapter, Search, GroupAdapter].includes(child.type);
    })
  };
}

export default function SideNavFullAdapter(props) {
  var _sortChildren = sortChildren(React.Children.toArray(props.children)),
      groups = _sortChildren.groups,
      links = _sortChildren.links,
      search = _sortChildren.search,
      otherChildren = _sortChildren.otherChildren;

  return React.createElement(
    HIGAdapter,
    _extends({
      displayName: "SideNavFull",
      HIGConstructor: VanillaGlobalNav._partials.SideNav._partials.SideNavFull
    }, props),
    function (adapterProps) {
      return React.createElement(
        "div",
        null,
        React.createElement(MountedByHIGParent, _extends({ mounter: "addContent" }, adapterProps)),
        React.createElement(MapsEventListener, _extends({
          listener: "onHeaderClick",
          handler: props.onHeaderClick
        }, adapterProps)),
        React.createElement(MapsEventListener, _extends({
          listener: "onSuperHeaderClick",
          handler: props.onSuperHeaderClick
        }, adapterProps)),
        React.createElement(MapsPropToMethod, _extends({
          value: props.headerLabel,
          setter: "setHeaderLabel"
        }, adapterProps)),
        React.createElement(MapsPropToMethod, _extends({
          value: props.headerLink,
          setter: "setHeaderLink"
        }, adapterProps)),
        React.createElement(MapsPropToMethod, _extends({
          value: props.superHeaderLabel,
          setter: "setSuperHeaderLabel"
        }, adapterProps)),
        React.createElement(MapsPropToMethod, _extends({
          value: props.superHeaderLink,
          setter: "setSuperHeaderLink"
        }, adapterProps)),
        React.createElement(MapsPropToMethod, _extends({
          value: props.copyright,
          setter: "setCopyright"
        }, adapterProps)),
        React.createElement(
          MapsPropToMethod,
          _extends({
            value: props.showVariantToggleButton
          }, adapterProps),
          function (instance, value) {
            return value ? instance.showVariantToggleButton() : instance.hideVariantToggleButton();
          }
        ),
        React.createElement(MapsEventListener, _extends({
          listener: "onVariantToggleClick",
          handler: props.onVariantToggleClick
        }, adapterProps)),
        otherChildren.length > 0 ? React.createElement(
          MountsAnyChild,
          _extends({ mounter: "addSlot" }, adapterProps),
          otherChildren
        ) : null,
        React.createElement(
          MountsHIGChild,
          adapterProps,
          search
        ),
        React.createElement(
          MountsHIGChildList,
          adapterProps,
          groups
        ),
        React.createElement(
          MountsHIGChildList,
          adapterProps,
          links
        )
      );
    }
  );
}

SideNavFullAdapter.propTypes = {
  children: PropTypes.node,
  copyright: PropTypes.string,
  onHeaderClick: PropTypes.func,
  onSuperHeaderClick: PropTypes.func,
  /**
   * Calls the provided callback when user clicks on the expand button
   */
  onVariantToggleClick: PropTypes.func,
  headerLabel: PropTypes.string,
  superHeaderLabel: PropTypes.string,
  headerLink: PropTypes.string,
  /**
   * Show or hide the collapse button
   */
  showVariantToggleButton: PropTypes.bool,
  superHeaderLink: PropTypes.string
};

SideNavFullAdapter.defaultProps = {
  children: undefined,
  copyright: undefined,
  onHeaderClick: undefined,
  onSuperHeaderClick: undefined,
  headerLabel: undefined,
  superHeaderLabel: undefined,
  headerLink: undefined,
  showVariantToggleButton: true,
  superHeaderLink: undefined
};
SideNavFullAdapter.__docgenInfo = {
  "description": "",
  "displayName": "SideNavFullAdapter",
  "props": {
    "children": {
      "type": {
        "name": "node"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "undefined",
        "computed": true
      }
    },
    "copyright": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "undefined",
        "computed": true
      }
    },
    "onHeaderClick": {
      "type": {
        "name": "func"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "undefined",
        "computed": true
      }
    },
    "onSuperHeaderClick": {
      "type": {
        "name": "func"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "undefined",
        "computed": true
      }
    },
    "onVariantToggleClick": {
      "type": {
        "name": "func"
      },
      "required": false,
      "description": "Calls the provided callback when user clicks on the expand button"
    },
    "headerLabel": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "undefined",
        "computed": true
      }
    },
    "superHeaderLabel": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "undefined",
        "computed": true
      }
    },
    "headerLink": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "undefined",
        "computed": true
      }
    },
    "showVariantToggleButton": {
      "type": {
        "name": "bool"
      },
      "required": false,
      "description": "Show or hide the collapse button",
      "defaultValue": {
        "value": "true",
        "computed": false
      }
    },
    "superHeaderLink": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "undefined",
        "computed": true
      }
    }
  }
};