var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import React from "react";
import PropTypes from "prop-types";
import { GlobalNav as VanillaGlobalNav } from "hig-vanilla";
import HIGAdapter, { MapsPropToMethod, MapsEventListener, MountedByHIGParent, MountsHIGChild } from "../../HIGAdapter";
import ShortcutAdapter from "./ShortcutAdapter";
import Search from "../../../elements/components/GlobalNav/TopNav/Search";
import Notifications from "../../../elements/components/GlobalNav/TopNav/Notifications";
import Profile from "../../../elements/components/GlobalNav/TopNav/Profile";
import HelpAdapter from "./HelpAdapter";
import ProjectAccountSwitcherAdapter from "./ProjectAccountSwitcherAdapter";
import ProjectAccountSwitcher from "../../../elements/components/GlobalNav/TopNav/ProjectAccountSwitcher"; // eslint-disable-line max-len

function sortChildren(children) {
  return {
    notifications: children.find(function (child) {
      return child.type === Notifications;
    }),
    shortcut: children.find(function (child) {
      return child.type === ShortcutAdapter;
    }),
    search: children.find(function (child) {
      return child.type === Search;
    }),
    profile: children.find(function (child) {
      return child.type === Profile;
    }),
    help: children.find(function (child) {
      return child.type === HelpAdapter;
    }),
    projectAccountSwitcher: children.find(function (child) {
      return [ProjectAccountSwitcher, ProjectAccountSwitcherAdapter].includes(child.type);
    })
  };
}

function TopNavAdapter(props) {
  var _sortChildren = sortChildren(React.Children.toArray(props.children)),
      notifications = _sortChildren.notifications,
      shortcut = _sortChildren.shortcut,
      search = _sortChildren.search,
      profile = _sortChildren.profile,
      help = _sortChildren.help,
      projectAccountSwitcher = _sortChildren.projectAccountSwitcher;

  return React.createElement(
    HIGAdapter,
    _extends({
      displayName: "TopNav",
      HIGConstructor: VanillaGlobalNav._partials.TopNav
    }, props),
    function (adapterProps) {
      return React.createElement(
        "div",
        null,
        React.createElement(MountedByHIGParent, _extends({ mounter: "addTopNav" }, adapterProps)),
        React.createElement(MapsPropToMethod, _extends({
          value: props.logo,
          setter: "setLogo"
        }, adapterProps)),
        React.createElement(MapsPropToMethod, _extends({
          value: props.logoLink,
          setter: "setLogoLink"
        }, adapterProps)),
        React.createElement(MapsPropToMethod, _extends({
          value: props.hideHamburgerButton,
          setter: "hideMenu"
        }, adapterProps)),
        React.createElement(MapsEventListener, _extends({
          handler: props.onLogoClick,
          listener: "onLogoClick"
        }, adapterProps)),
        React.createElement(MapsEventListener, _extends({
          handler: props.onHamburgerClick,
          listener: "onHamburgerClick"
        }, adapterProps)),
        React.createElement(
          MountsHIGChild,
          adapterProps,
          shortcut
        ),
        React.createElement(
          MountsHIGChild,
          adapterProps,
          search
        ),
        React.createElement(
          MountsHIGChild,
          adapterProps,
          profile
        ),
        React.createElement(
          MountsHIGChild,
          adapterProps,
          notifications
        ),
        React.createElement(
          MountsHIGChild,
          adapterProps,
          help
        ),
        React.createElement(
          MountsHIGChild,
          adapterProps,
          projectAccountSwitcher
        )
      );
    }
  );
}

TopNavAdapter.propTypes = {
  children: PropTypes.node,
  hideHamburgerButton: PropTypes.bool,
  logo: PropTypes.string,
  logoLink: PropTypes.string,
  onLogoClick: PropTypes.func,
  onHamburgerClick: PropTypes.func
};

TopNavAdapter.defaultProps = {
  children: undefined,
  hideHamburgerButton: false,
  logo: undefined,
  logoLink: undefined,
  onLogoClick: undefined,
  onHamburgerClick: undefined
};

export default TopNavAdapter;
TopNavAdapter.__docgenInfo = {
  "description": "",
  "displayName": "TopNavAdapter",
  "props": {
    "children": {
      "type": {
        "name": "node"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "undefined",
        "computed": true
      }
    },
    "hideHamburgerButton": {
      "type": {
        "name": "bool"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "false",
        "computed": false
      }
    },
    "logo": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "undefined",
        "computed": true
      }
    },
    "logoLink": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "undefined",
        "computed": true
      }
    },
    "onLogoClick": {
      "type": {
        "name": "func"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "undefined",
        "computed": true
      }
    },
    "onHamburgerClick": {
      "type": {
        "name": "func"
      },
      "required": false,
      "description": "",
      "defaultValue": {
        "value": "undefined",
        "computed": true
      }
    }
  }
};