var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from "react";
import PropTypes from "prop-types";

import DropdownAdapter from "../../../adapters/FormElements/DropdownAdapter";
import Option from "./Option";

var Dropdown = function (_Component) {
  _inherits(Dropdown, _Component);

  function Dropdown(props) {
    _classCallCheck(this, Dropdown);

    var _this = _possibleConstructorReturn(this, (Dropdown.__proto__ || Object.getPrototypeOf(Dropdown)).call(this, props));

    _this.setSelectedValue = function (selectedOptionValue) {
      _this.props.onChange(selectedOptionValue);

      _this.setState({
        open: false,
        value: selectedOptionValue
      });
    };

    _this.openDropdown = function () {
      _this.setState({ open: true });
    };

    _this.closeDropdown = function () {
      _this.setState({ open: false });
    };

    _this.handleOptionHover = function (focusedOptionIndex) {
      return function () {
        return _this.setState({ focusedOptionIndex: focusedOptionIndex });
      };
    };

    _this.handleOptionSelect = function () {
      var selectedOption = _this.props.options[_this.state.focusedOptionIndex];
      _this.setSelectedValue(selectedOption.value);
      _this.hideOptions();
    };

    _this.hideOptions = function () {
      _this.setState({ open: false, focusedOptionIndex: undefined });
    };

    _this.handleKeydown = function (event) {
      switch (event.keyCode) {
        case 40:
          event.preventDefault();
          _this.focusPrevious();
          break;
        case 37:
          event.preventDefault();
          _this.focusPrevious();
          break;
        case 38:
          event.preventDefault();
          _this.focusNext();
          break;
        case 39:
          event.preventDefault();
          _this.focusNext();
          break;
        case 13:
          _this.handleEnterPress(event.target.value);
          break;
        default:
          break;
      }
    };

    _this.state = {
      open: false,
      value: _this.getDefaultValue()
    };
    return _this;
  }

  _createClass(Dropdown, [{
    key: "getDefaultValue",
    value: function getDefaultValue() {
      var _props = this.props,
          defaultValue = _props.defaultValue,
          value = _props.value;


      if (value !== undefined) {
        return value;
      } else if (defaultValue !== undefined) {
        return defaultValue;
      }
      return "";
    }
  }, {
    key: "getRenderedValue",
    value: function getRenderedValue() {
      var value = this.props.value;


      if (value !== undefined) {
        return value;
      }
      return this.state.value;
    }
  }, {
    key: "handleEnterPress",
    value: function handleEnterPress(selectedValue) {
      if (this.state.focusedOptionIndex !== undefined) {
        this.handleOptionSelect(selectedValue);
        return;
      }

      this.props.onSubmit({ selectedValue: selectedValue });
      this.hideOptions();
    }
  }, {
    key: "focusPrevious",
    value: function focusPrevious() {
      if (this.state.focusedOptionIndex === undefined || this.state.focusedOptionIndex >= this.props.options.length - 1) {
        this.setState({ focusedOptionIndex: 0, open: true });
      } else {
        var focusedOptionIndex = this.state.focusedOptionIndex + 1;
        this.setState({ focusedOptionIndex: focusedOptionIndex, open: true });
      }
    }
  }, {
    key: "focusNext",
    value: function focusNext() {
      if (this.state.focusedOptionIndex === undefined || this.state.focusedOptionIndex <= 0) {
        var focusedOptionIndex = this.props.options.length - 1;
        this.setState({ focusedOptionIndex: focusedOptionIndex, open: true });
      } else {
        var _focusedOptionIndex = this.state.focusedOptionIndex - 1;
        this.setState({ focusedOptionIndex: _focusedOptionIndex, open: true });
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var selectedOption = this.props.options.find(function (o) {
        return o.value === _this2.getRenderedValue();
      }) || {};

      return React.createElement(
        DropdownAdapter,
        _extends({}, this.props, {
          open: this.state.open,
          selectedOptionLabel: selectedOption.label,
          onTargetClick: this.openDropdown,
          onClickOutside: this.closeDropdown,
          onKeydown: this.handleKeydown
        }),
        this.props.options.map(function (option, index) {
          return React.createElement(Option, _extends({
            key: option.value
          }, option, {
            selected: option.value === selectedOption.value,
            focused: index === _this2.state.focusedOptionIndex,
            checked: option.value === selectedOption.value,
            onClick: _this2.handleOptionSelect,
            onHover: _this2.handleOptionHover(index)
          }));
        })
      );
    }
  }]);

  return Dropdown;
}(Component);

Dropdown.defaultProps = {
  options: [],
  onChange: function onChange() {}
};
export default Dropdown;


Dropdown.propTypes = {
  /**
   * {string} label for the the dropdown
   */
  label: PropTypes.string,
  /**
   * {string} instructions for the dropdown
   */
  instructions: PropTypes.string,
  /**
   * {string} placeholder for the dropdown
   */
  placeholder: PropTypes.string,
  /**
   * {bool} makes the dropdown disabled
   */
  disabled: PropTypes.bool,
  /**
   * {string} makes the field required
   */
  required: PropTypes.string,
  /**
   * {string} option that is selected on construction
   */
  value: PropTypes.string,
  /**
   * {string} default selected option
   */
  defaultValue: PropTypes.string,
  /**
   * {Array} array with objects, objects have a 'label' and a 'value'
   */
  options: PropTypes.arrayOf(PropTypes.shape({
    label: PropTypes.string,
    value: PropTypes.string
  })),
  /**
   * Calls the provided callback when option is changed
   */
  onChange: PropTypes.func,
  /**
   * Calls the provided callback when focus moves away from the dropdown
   */
  onBlur: PropTypes.func,
  /**
   * Calls the provided callback when the user focuses on the dropdown
   */
  onFocus: PropTypes.func,
  /**
   * Calls the provided callback when the user presses a key while the dropdown has focus
   */
  onKeydown: PropTypes.func
  /**
   * Calls the provided callback when user presses Enter key while the Dropdown has focus
   */
};
Dropdown.__docgenInfo = {
  "description": "",
  "displayName": "Dropdown",
  "props": {
    "label": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": "{string} label for the the dropdown"
    },
    "instructions": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": "{string} instructions for the dropdown"
    },
    "placeholder": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": "{string} placeholder for the dropdown"
    },
    "disabled": {
      "type": {
        "name": "bool"
      },
      "required": false,
      "description": "{bool} makes the dropdown disabled"
    },
    "required": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": "{string} makes the field required"
    },
    "value": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": "{string} option that is selected on construction"
    },
    "defaultValue": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": "{string} default selected option"
    },
    "options": {
      "type": {
        "name": "arrayOf",
        "value": {
          "name": "shape",
          "value": {
            "label": {
              "name": "string",
              "required": false
            },
            "value": {
              "name": "string",
              "required": false
            }
          }
        }
      },
      "required": false,
      "description": "{Array} array with objects, objects have a 'label' and a 'value'",
      "defaultValue": {
        "value": "[]",
        "computed": false
      }
    },
    "onChange": {
      "type": {
        "name": "func"
      },
      "required": false,
      "description": "Calls the provided callback when option is changed",
      "defaultValue": {
        "value": "() => {}",
        "computed": false
      }
    },
    "onBlur": {
      "type": {
        "name": "func"
      },
      "required": false,
      "description": "Calls the provided callback when focus moves away from the dropdown"
    },
    "onFocus": {
      "type": {
        "name": "func"
      },
      "required": false,
      "description": "Calls the provided callback when the user focuses on the dropdown"
    },
    "onKeydown": {
      "type": {
        "name": "func"
      },
      "required": false,
      "description": "Calls the provided callback when the user presses a key while the dropdown has focus"
    }
  }
};