var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

export function match(string, query) {
  return string.toLowerCase().startsWith(query.toLowerCase());
}

export function filter(_ref, query) {
  var modules = _ref.modules,
      submodules = _ref.submodules,
      props = _objectWithoutProperties(_ref, ["modules", "submodules"]);

  var filteredSubmodules = submodules.filter(function (submodule) {
    return match(submodule.title, query);
  });
  var filteredModules = modules.filter(function (module) {
    return filteredSubmodules.some(function (s) {
      return s.moduleId === module.id;
    }) || match(module.title, query);
  });

  return _extends({}, props, { modules: filteredModules, submodules: filteredSubmodules });
}

export function group(_ref2) {
  var modules = _ref2.modules,
      submodules = _ref2.submodules;

  var uniqueGroupIds = Array.from(new Set(modules.map(function (m) {
    return m.groupId;
  })));
  return uniqueGroupIds.map(function (groupId) {
    return {
      modules: modules.filter(function (m) {
        return m.groupId === groupId;
      }).map(function (module) {
        return _extends({}, module, {
          submodules: submodules.filter(function (s) {
            return s.moduleId === module.id;
          })
        });
      })
    };
  });
}

export function getModuleState(moduleStates, id) {
  var state = moduleStates[id] || {};

  if (state.minimized === undefined) {
    state.minimized = true;
  }
  return state;
}

export function mergeState(_ref3, state) {
  var modules = _ref3.modules,
      submodules = _ref3.submodules,
      props = _objectWithoutProperties(_ref3, ["modules", "submodules"]);

  var activeModuleId = props.activeModuleId || state.activeModuleId;
  var activeModule = modules.find(function (m) {
    return m.id === activeModuleId;
  }) || {};
  var activeSubmodule = submodules.find(function (m) {
    return m.id === activeModuleId;
  }) || {};

  return _extends({}, props, {
    modules: modules.map(function (module) {
      var moduleWithState = _extends({}, module, {
        active: module.id === activeModule.id,
        activeChildren: module.id === activeSubmodule.moduleId
      }, getModuleState(state.moduleStates, module.id));

      return moduleWithState;
    }),
    submodules: submodules.map(function (submodule) {
      return _extends({}, submodule, {
        active: submodule.id === activeModuleId
      });
    })
  });
}