var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import { Table as VanillaTable } from "hig-vanilla";
import PropTypes from "prop-types";
import React, { Component } from "react";
import HeaderCheckbox from "./HeaderCheckbox";
import RowCheckbox from "./RowCheckbox";

var SelectableTable = function (_Component) {
  _inherits(SelectableTable, _Component);

  function SelectableTable(props) {
    _classCallCheck(this, SelectableTable);

    var _this = _possibleConstructorReturn(this, (SelectableTable.__proto__ || Object.getPrototypeOf(SelectableTable)).call(this, props));

    _initialiseProps.call(_this);

    _this.state = {
      rows: {},
      allRowsSelected: false
    };
    return _this;
  }

  _createClass(SelectableTable, [{
    key: "isRowSelected",
    value: function isRowSelected(row) {
      if (row.selected !== undefined) {
        return row.selected;
      } else if (this.state.rows[row.id] && this.state.rows[row.id].selected) {
        return this.state.rows[row.id].selected;
      }
      return false;
    }
  }, {
    key: "renderedAllRowsSelected",
    value: function renderedAllRowsSelected() {
      if (this.props.allRowsSelected !== undefined) {
        return this.props.allRowsSelected;
      }
      return this.state.allRowsSelected;
    }
  }, {
    key: "render",
    value: function render() {
      var columns = [this.checkboxHeader()].concat(this.props.columns);
      var enhancedData = this.props.data.map(this.mergeRowState);
      return this.props.children(columns, enhancedData, this.props.density);
    }
  }]);

  return SelectableTable;
}(Component);

SelectableTable.defaultProps = {
  columns: [],
  data: [],
  onSelectAllSelectionChange: function onSelectAllSelectionChange() {},
  onRowSelectionChange: function onRowSelectionChange() {}
};

var _initialiseProps = function _initialiseProps() {
  var _this2 = this;

  this.selectRow = function (rowInfo) {
    var newRows = _extends({}, _this2.state.rows, _defineProperty({}, rowInfo.id, { selected: rowInfo.selected }));
    _this2.setState({ rows: newRows });
  };

  this.handleAllSelectionChange = function (event) {
    _this2.setState({ allRowsSelected: event.target.checked });
    _this2.props.onSelectAllSelectionChange({ selected: event.target.checked });
  };

  this.handleRowCheckboxOnChange = function (rowInfo) {
    _this2.selectRow(rowInfo);
    _this2.props.onRowSelectionChange(rowInfo);
  };

  this.checkboxHeader = function () {
    return {
      id: "checkboxHeader",
      alignment: "center",
      width: "50px",
      HeaderCell: function HeaderCell() {
        return React.createElement(HeaderCheckbox, {
          onSelectAllSelectionChange: _this2.handleAllSelectionChange,
          selected: _this2.renderedAllRowsSelected(),
          style: { background: "red" }
        });
      },
      Cell: function Cell(props) {
        return React.createElement(RowCheckbox, {
          id: props.data.id,
          selected: props.data.selected,
          onChange: _this2.handleRowCheckboxOnChange
        });
      }
    };
  };

  this.mergeRowState = function (row) {
    return _extends({}, row, {
      selected: _this2.isRowSelected(row)
    });
  };
};

export default SelectableTable;


SelectableTable.propTypes = {
  /**
   * Sets the size of the table
   */
  density: PropTypes.oneOf(VanillaTable.AvailableDensities),
  /**
   * Provides content table cells
   */
  data: PropTypes.arrayOf(PropTypes.object),
  /**
   * Called when user selects or deselects a row
   */
  onRowSelectionChange: PropTypes.func,
  /**
   * Function to render the table. Signature is fn(columns, data, density)
   */
  children: PropTypes.func,
  /**
   * Called when user checks or unchecks the select-all checkbox
   */
  onSelectAllSelectionChange: PropTypes.func,
  /**
   * Provides content for header cells
   */
  columns: PropTypes.arrayOf(PropTypes.shape({
    Header: PropTypes.string,
    alignment: PropTypes.alignment,
    width: PropTypes.string,
    id: PropTypes.string,
    Cell: PropTypes.any
  }))
};
SelectableTable.__docgenInfo = {
  "description": "",
  "displayName": "SelectableTable",
  "props": {
    "density": {
      "type": {
        "name": "enum",
        "computed": true,
        "value": "VanillaTable.AvailableDensities"
      },
      "required": false,
      "description": "Sets the size of the table"
    },
    "data": {
      "type": {
        "name": "arrayOf",
        "value": {
          "name": "object"
        }
      },
      "required": false,
      "description": "Provides content table cells",
      "defaultValue": {
        "value": "[]",
        "computed": false
      }
    },
    "onRowSelectionChange": {
      "type": {
        "name": "func"
      },
      "required": false,
      "description": "Called when user selects or deselects a row",
      "defaultValue": {
        "value": "() => {}",
        "computed": false
      }
    },
    "children": {
      "type": {
        "name": "func"
      },
      "required": false,
      "description": "Function to render the table. Signature is fn(columns, data, density)"
    },
    "onSelectAllSelectionChange": {
      "type": {
        "name": "func"
      },
      "required": false,
      "description": "Called when user checks or unchecks the select-all checkbox",
      "defaultValue": {
        "value": "() => {}",
        "computed": false
      }
    },
    "columns": {
      "type": {
        "name": "arrayOf",
        "value": {
          "name": "shape",
          "value": {
            "Header": {
              "name": "string",
              "required": false
            },
            "alignment": {
              "name": "custom",
              "raw": "PropTypes.alignment",
              "required": false
            },
            "width": {
              "name": "string",
              "required": false
            },
            "id": {
              "name": "string",
              "required": false
            },
            "Cell": {
              "name": "any",
              "required": false
            }
          }
        }
      },
      "required": false,
      "description": "Provides content for header cells",
      "defaultValue": {
        "value": "[]",
        "computed": false
      }
    }
  }
};