var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import { Table as VanillaTable } from "hig-vanilla";
import PropTypes from "prop-types";
import React, { Component } from "react";
import TableAdapter from "../../../adapters/Table/TableAdapter";
import TableHeadAdapter from "../../../adapters/Table/TableHeadAdapter";
import TableRowAdapter from "../../../adapters/Table/TableRowAdapter";
import TextHeadCellAdapter from "../../../adapters/Table/TextHeadCellAdapter";
import TextCell from "../../../adapters/Table/TextCellAdapter";
import SlotCell from "../../../adapters/Table/SlotCellAdapter";

import SlotHeadCell from "../../../adapters/Table/SlotHeadCellAdapter";
import SelectableTable from "./SelectableTable";

function getCell(props) {
  var content = void 0;
  switch (_typeof(props.column.accessor)) {
    case "function":
      {
        content = props.column.accessor(props.data);
        break;
      }
    default:
      {
        content = props.data[props.column.accessor];
      }
  }

  if (props.column.Cell) {
    return React.createElement(
      SlotCell,
      { key: props.column.id },
      React.createElement(props.column.Cell, props)
    );
  }
  return React.createElement(TextCell, { key: props.column.id, text: content });
}

function getHeadCell(props) {
  if (typeof props.column.HeaderCell === "string") {
    return React.createElement(TextHeadCellAdapter, {
      key: props.column.id,
      text: props.column.HeaderCell,
      alignment: props.column.alignment,
      width: props.column.width
    });
  }
  return React.createElement(
    SlotHeadCell,
    { key: props.column.id, width: props.column.width },
    React.createElement(props.column.HeaderCell, props)
  );
}

var Table = function (_Component) {
  _inherits(Table, _Component);

  function Table() {
    var _ref;

    var _temp, _this, _ret;

    _classCallCheck(this, Table);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = Table.__proto__ || Object.getPrototypeOf(Table)).call.apply(_ref, [this].concat(args))), _this), _this.renderTable = function (columns, data, density) {
      return React.createElement(
        TableAdapter,
        { density: density },
        React.createElement(
          TableHeadAdapter,
          null,
          columns.map(function (column, index) {
            return getHeadCell({ column: column, index: index });
          })
        ),
        data.map(function (row) {
          return React.createElement(
            TableRowAdapter,
            { key: row.id, selected: row.selected },
            columns.map(function (column, index) {
              return getCell({ column: column, data: row, index: index });
            })
          );
        })
      );
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  _createClass(Table, [{
    key: "render",
    value: function render() {
      var isSelectable = this.props.selectable;
      return React.createElement(
        "div",
        null,
        isSelectable ? React.createElement(
          SelectableTable,
          _extends({
            columns: this.props.columns,
            data: this.props.data
          }, this.props),
          this.renderTable
        ) : this.renderTable(this.props.columns, this.props.data, this.props.density)
      );
    }
  }]);

  return Table;
}(Component);

Table.defaultProps = {
  columns: [],
  data: [],
  selectable: false,
  density: undefined
};
export default Table;


Table.propTypes = {
  /**
   * Provides content for header cells
   */
  columns: PropTypes.arrayOf(PropTypes.shape({
    Header: PropTypes.string,
    alignment: PropTypes.alignment,
    width: PropTypes.string,
    id: PropTypes.string,
    Cell: PropTypes.any
  })),
  /**
   * Provides content table cells
   */
  data: PropTypes.arrayOf(PropTypes.object),
  /**
   * Sets the size of the table
   */
  density: PropTypes.oneOf(VanillaTable.AvailableDensities),
  /**
   * Called when user selects or deselects a row
   */
  onRowSelectionChange: PropTypes.func,
  /**
   * Called when user checks or unchecks the select-all checkbox
   */
  onSelectAllSelectionChange: PropTypes.func,
  /**
   * When true, adds checkboxes to each row, and a select-all checkbox to the header
   */
  selectable: PropTypes.bool
};
Table.__docgenInfo = {
  "description": "",
  "displayName": "Table",
  "props": {
    "columns": {
      "type": {
        "name": "arrayOf",
        "value": {
          "name": "shape",
          "value": {
            "Header": {
              "name": "string",
              "required": false
            },
            "alignment": {
              "name": "custom",
              "raw": "PropTypes.alignment",
              "required": false
            },
            "width": {
              "name": "string",
              "required": false
            },
            "id": {
              "name": "string",
              "required": false
            },
            "Cell": {
              "name": "any",
              "required": false
            }
          }
        }
      },
      "required": false,
      "description": "Provides content for header cells",
      "defaultValue": {
        "value": "[]",
        "computed": false
      }
    },
    "data": {
      "type": {
        "name": "arrayOf",
        "value": {
          "name": "object"
        }
      },
      "required": false,
      "description": "Provides content table cells",
      "defaultValue": {
        "value": "[]",
        "computed": false
      }
    },
    "density": {
      "type": {
        "name": "enum",
        "computed": true,
        "value": "VanillaTable.AvailableDensities"
      },
      "required": false,
      "description": "Sets the size of the table",
      "defaultValue": {
        "value": "undefined",
        "computed": true
      }
    },
    "onRowSelectionChange": {
      "type": {
        "name": "func"
      },
      "required": false,
      "description": "Called when user selects or deselects a row"
    },
    "onSelectAllSelectionChange": {
      "type": {
        "name": "func"
      },
      "required": false,
      "description": "Called when user checks or unchecks the select-all checkbox"
    },
    "selectable": {
      "type": {
        "name": "bool"
      },
      "required": false,
      "description": "When true, adds checkboxes to each row, and a select-all checkbox to the header",
      "defaultValue": {
        "value": "false",
        "computed": false
      }
    }
  }
};